@@ -58,7 +58,7 @@ class Users():
       if len(roles) > 0:
          for role in roles:
                rolelist.append({"role_name": role})
-         user_def.append({"roles":rolelist})
+         user_def.update({"roles":rolelist})
 
       if type == "API":
          user_def.update({"user_name": username})
@@ -70,6 +70,11 @@ class Users():
          if len(roles) == 0:
             rolelist.append({"role_name":"submitter"}) 
 
+      if username is not None:
+         user_def.update({"user_name": username})
+      else:
+         user_def.update({"user_name": email})
+
       teamlist = []
       if len(teams) > 0:
          for team in teams:
@@ -81,10 +86,22 @@ class Users():
       payload = json.dumps(user_def)
       return APIHelper()._rest_request('api/authn/v2/users','POST',body=payload)
 
-   def update(self,user_guid,roles):
+   def update_roles(self,user_guid,roles):
+      request_params = {'partial': 'TRUE',"incremental": 'TRUE'}
+      uri = "api/authn/v2/users/{}".format(user_guid)
+
+      rolelist = []
+      for role in roles:
+            rolelist.append({"role_name": role})
+
+      payload = json.dumps({"roles": rolelist})
+      return APIHelper()._rest_request(uri,"PUT",request_params,body=payload)
+
+   def update(self,user_guid,changes):
       request_params = {'partial':'TRUE',"incremental": 'TRUE'}
       uri = "api/authn/v2/users/{}".format(user_guid)
-      return APIHelper()._rest_request(uri,"PUT",request_params,roles)  
+      payload = json.dumps(changes)
+      return APIHelper()._rest_request(uri,"PUT",request_params,body=payload)
 
    def disable(self,user_guid):
       request_params = {'partial':'TRUE'}
